@@ -52,7 +52,7 @@ sub install($) {
         return;
     }
 
-    debug_say("installing perl6 module $module...");
+    debug_say("installing raku module $module...");
     my $tmpdir = Path::Tiny->tempdir;
     my $build_dir = $tmpdir->child('build');
     $build_dir->mkpath;
@@ -90,7 +90,7 @@ sub remove($) {
     }
 
     if ($module_list_path->exists) {
-        debug_say("removing perl6 module $module...");
+        debug_say("removing raku module $module...");
         foreach my $file ($module_list_path->lines({chomp => 1})) {
             # do not delete files shipped by package. (i.e. packages
             # that ship pre-compiled files)
@@ -114,7 +114,7 @@ sub remove($) {
 
 sub reinstall_all() {
     # remove all existing precompiled files
-    debug_say("reinstalling all perl6 modules on system...");
+    debug_say("reinstalling all raku modules on system...");
     foreach my $list ($varlib->children(qr/\.list$/)) {
         my $module = $list->basename =~ s/\.list$//r;
         debug_say("deleting old precompiled files of module $module");
@@ -158,7 +158,7 @@ Where [arguments] can be one of:
   --install -i <package> install perl modules from specified package
                          into rakudo distribution
   --remove -r <package>  remove files created by --install
-  --reinstall-all        reinstall all perl6 module packages on the system
+  --reinstall-all        reinstall all raku module packages on the system
   --compiler-id -c       print the rakudo compiler id
   --help -h              show this text
 EOF
